@@ -15,6 +15,7 @@
 #include "trace.h"
 #include "progress.h"
 #include "progressdialog.h"
+#include "platform.h"
 
 BookView::BookView(QWidget *parent):
     QWebView(parent), contentIndex(-1), mBook(0),
@@ -29,7 +30,8 @@ BookView::BookView(QWidget *parent):
     settings()->setAttribute(QWebSettings::PrivateBrowsingEnabled, true);
     settings()->setAttribute(QWebSettings::JavascriptCanOpenWindows, false);
     settings()->setAttribute(QWebSettings::JavascriptCanAccessClipboard, false);
-    settings()->setAttribute(QWebSettings::OfflineStorageDatabaseEnabled, false);
+    settings()->setAttribute(QWebSettings::OfflineStorageDatabaseEnabled,
+                             false);
     settings()->setAttribute(QWebSettings::OfflineWebApplicationCacheEnabled,
                              false);
     settings()->setAttribute(QWebSettings::LocalStorageEnabled, false);
@@ -60,15 +62,7 @@ BookView::BookView(QWidget *parent):
             this, SLOT(onSettingsChanged(const QString &)));
     Settings *s = Settings::instance();
     s->setValue("zoom", s->value("zoom", 160));
-    s->setValue("font", s->value("font",
-#if defined(Q_WS_MAEMO_5) || defined(Q_WS_X11)
-                                 "Serif"
-#elif defined(Q_WS_MAC)
-                                 "Hoefler Text"
-#else
-                                 "Times New Roman"
-#endif
-                                 ));
+    s->setValue("font", s->value("font", Platform::defaultFont()));
     s->setValue("scheme", s->value("scheme", "default"));
     setBook(0);
 
@@ -99,8 +93,7 @@ void BookView::loadContent(int index)
     QString contentFile(mBook->content[mBook->parts[index]].href);
     if (mBook->parts[index] == "error") {
         setHtml(contentFile);
-    }
-    else {
+    } else {
         loaded = false;
         emit partLoadStart(index);
         QUrl u = QUrl::fromLocalFile(QDir(mBook->rootPath()).
@@ -197,6 +190,33 @@ void BookView::goToBookmark(const Book::Bookmark &bookmark)
     }
 }
 
+void BookView::goToPart(int part, const QString &fragment)
+{
+    TRACE;
+    if (mBook) {
+        if (part != contentIndex) {
+            qDebug() << "Loading new part" << part;
+            restoreFragmentAfterLoad = true;
+            fragmentAfterLoad = fragment;
+            loadContent(part);
+        } else {
+            goToFragment(fragment);
+            showProgress();
+        }
+    }
+}
+
+void BookView::goToFragment(const QString &fragment)
+{
+    TRACE;
+    if (!fragment.isEmpty()) {
+        QVariant ret = page()->mainFrame()->evaluateJavaScript(
+                QString("window.location='") + fragment + "'");
+        qDebug() << ret;
+        setLastBookmark();
+    }
+}
+
 void BookView::onLoadFinished(bool ok)
 {
     TRACE;
@@ -213,11 +233,13 @@ void BookView::onLoadFinished(bool ok)
 void BookView::onSettingsChanged(const QString &key)
 {
     TRACE;
+    qDebug() << key << Settings::instance()->value(key);
+
     if (key == "zoom") {
         setZoomFactor(Settings::instance()->value(key).toFloat() / 100.);
     }
     else if (key == "font") {
-        QString face = Settings::instance()->value("font").toString();
+        QString face = Settings::instance()->value(key).toString();
         settings()->setFontFamily(QWebSettings::StandardFont, face);
     }
     else if (key == "scheme") {
@@ -348,14 +370,21 @@ void BookView::addJavaScriptObjects()
 
 void BookView::onContentsSizeChanged(const QSize &size)
 {
+    TRACE;
     contentsHeight = size.height();
-    if (restorePositionAfterLoad) {
-        qDebug() << "BookView::onContentSizeChanged: Time to restore";
-        restorePositionAfterLoad = false;
+    if (restoreFragmentAfterLoad) {
+        qDebug() << "Restorint to fragment" << fragmentAfterLoad;
+        goToFragment(fragmentAfterLoad);
+    } else if (restorePositionAfterLoad) {
+        qDebug() << "Restoring to position";
         goToPosition(positionAfterLoad);
     }
+    restorePositionAfterLoad = false;
+    restoreFragmentAfterLoad = false;
 }
 
+#ifdef Q_WS_MAEMO_5
+
 void BookView::leaveEvent(QEvent *e)
 {
     TRACE;
@@ -373,6 +402,8 @@ void BookView::enterEvent(QEvent *e)
     QWebView::enterEvent(e);
 }
 
+#endif // Q_WS_MAEMO_5
+
 void BookView::goToPosition(qreal position)
 {
     int scrollPos = (int)((qreal)contentsHeight * position);
