@@ -224,8 +224,8 @@ void MainWindow::showRegular()
     view->restoreLastBookmark();
 #endif
     progress->flash();
-    nextButton->flash(1500);
-    previousButton->flash(1500);
+    nextButton->flash();
+    previousButton->flash();
 }
 
 void MainWindow::showBig()
@@ -259,8 +259,8 @@ void MainWindow::showBig()
     fullScreenWindow->activateWindow();
 #endif
     progress->flash();
-    nextButton->flash(1500);
-    previousButton->flash(1500);
+    nextButton->flash();
+    previousButton->flash();
 }
 
 void MainWindow::setCurrentBook(const QModelIndex &current)
@@ -317,7 +317,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 
 void MainWindow::onSettingsChanged(const QString &key)
 {
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5)
     if (key == "orientation") {
         QString value = Settings::instance()->value(key).toString();
         qDebug() << "MainWindow::onSettingsChanged: orientation" << value;
@@ -377,6 +377,13 @@ void MainWindow::onAddBookmark(const QString &note)
 {
     TRACE;
     view->addBookmark(note);
+#ifdef Q_WS_MAEMO_5
+    QMaemo5InformationBox::information(this,
+        tr("Bookmarked current position"), QMaemo5InformationBox::DefaultTimeout);
+#else
+    (void)QMessageBox::information(this, tr("Dorian"),
+        tr("Bookmarked current position"), QMessageBox::Ok);
+#endif // Q_WS_MAEMO_5}
 }
 
 void MainWindow::onGoToBookmark(int index)
@@ -404,9 +411,10 @@ void MainWindow::onGoToChapter(int index)
 
     Book *book = Library::instance()->book(mCurrent);
     if (book) {
-        int partIndex = book->partFromChapter(index);
+        QString fragment;
+        int partIndex = book->partFromChapter(index, fragment);
         if (partIndex != -1) {
-            view->goToBookmark(Book::Bookmark(partIndex, 0));
+            view->goToPart(partIndex, fragment);
         }
     }
 }
@@ -446,8 +454,8 @@ void MainWindow::resizeEvent(QResizeEvent *e)
         toolBar->height(), TranslucentButton::pixels, TranslucentButton::pixels);
 #endif // Q_WS_MAEMO_5
     qDebug() << "previousButton geometry" << previousButton->geometry();
-    previousButton->flash(1500);
-    nextButton->flash(1500);
+    previousButton->flash();
+    nextButton->flash();
     QMainWindow::resizeEvent(e);
 }
 
@@ -462,7 +470,7 @@ void MainWindow::about()
     label->setText(tr("<b>Dorian %1</b><br><br>Copyright &copy; 2010 "
         "Akos Polster &lt;akos@pipacs.com&gt;<br>"
         "Licensed under GNU General Public License, Version 3<br>"
-        "Source code: <a href='https://garage.maemo.org/projects/dorian/'>"
+        "Source code:<br><a href='https://garage.maemo.org/projects/dorian/'>"
         "garage.maemo.org/projects/dorian</a>").arg(Platform::version()));
     aboutDialog->addWidget(label);
     aboutDialog->addStretch();
@@ -472,15 +480,15 @@ void MainWindow::about()
 
 void MainWindow::goToNextPage()
 {
-    nextButton->flash(1500);
-    previousButton->flash(1500);
+    nextButton->flash();
+    previousButton->flash();
     view->goNextPage();
 }
 
 void MainWindow::goToPreviousPage()
 {
-    nextButton->flash(1500);
-    previousButton->flash(1500);
+    nextButton->flash();
+    previousButton->flash();
     view->goPreviousPage();
 }
 
